netapp_ontap.models.data_collection_metrics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_collection_metrics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataCollectionMetricsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataCollectionMetrics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `counts_by_state: List[DataCollectionMetricsCountsByState] GET`

    The number of data collections per state.

  `space_percent: Size GET`

    The percentage of the total cluster size occupied by the data collections.

    Example: 25

  `total_count: Size GET`

    The total number of data collections.

    Example: 100

  `total_size: Size GET`

    The total size of all data collections, in bytes.

    Example: 121314